@@ -84,7 +84,7 @@ burn_os_is_2k_seekrw()  tells whether the given path leads to a file object
 
 burn_os_stdio_capacity()  estimates the emulated media space of stdio-drives.
 
-burn_os_open_track_src()  opens a disk file in a way that allows best
+burn_os_open_track_src()  opens a disk file in a way that offers best
                         throughput with file reading and/or SCSI write command
                         transmission.
 
@@ -219,14 +219,6 @@ static char linux_ata_device_family[80] = {"/dev/hd%c"};
 static int linux_ata_enumerate_verbous = 0;
 
 
-/* The waiting time before eventually retrying a failed SCSI command.
-   Before each retry wait Libburn_sg_linux_retry_incR longer than with
-   the previous one.
-*/
-#define Libburn_sg_linux_retry_usleeP 100000
-#define Libburn_sg_linux_retry_incR   100000
-
-
 /** PORTING : ------ libburn portable headers and definitions ----- */
 
 #include "libburn.h"
@@ -386,15 +378,19 @@ static int sg_exchange_scd_for_sr(char *fname, int flag)
 static int sgio_log_cmd(unsigned char *cmd, int cmd_len, FILE *fp_in, int flag)
 {
 	FILE *fp = fp_in;
-	int ret;
+	int ret = 0;
 
 	/* >>> ts B11110 : move this into scsi_log_command() */
 	if (fp == NULL && (burn_sg_log_scsi & 1)) {
 		fp= fopen("/tmp/libburn_sg_command_log", "a");
-		fprintf(fp, "\n=========================================\n");
+		if (fp != NULL)
+			fprintf(fp,
+			    "\n=========================================\n");
 	}
 
-	ret = scsi_log_command(cmd, cmd_len, NO_TRANSFER, NULL, 0, fp, flag);
+	if (fp != NULL)
+		ret = scsi_log_command(cmd, cmd_len, NO_TRANSFER, NULL, 0,
+					fp, flag);
 	if (fp_in == NULL && fp != NULL)
 		fclose(fp);
 	return ret;
@@ -1421,7 +1417,7 @@ static int add_proc_info_drives(int flag)
 	char **list= NULL;
 
 	if (burn_sg_use_family != 0)
-		return(1); /* Looking only for sr resp. scd resp. sg */
+		return(1); /* Looking only for sr , scd , sg */
 
 	ret = proc_sys_dev_cdrom_info(&list, &list_count, 0);
 	if (ret <= 0)
@@ -1624,6 +1620,8 @@ next_ata:;
 
 next_proc_info:;
 	baseno += ata_limit;
+	if (burn_sg_use_family != 0) /* Only with default enumeration */
+		return 0;
 	for (i = 0; i < idx->info_count; i++) {
 		if ((idx->info_list)[i][0] == 0)
 	continue;
@@ -1659,7 +1657,7 @@ return_1_pre_proc:;
     and accessability. If burn activities are prone to external interference
     on your system it is also necessary to obtain exclusive access locks on
     the drives.
-    Hand over each accepted drive to enumerate_common() resp. its replacement
+    Hand over each accepted drive to enumerate_common() or its replacement
     within your port.
 
     See FreeBSD port sketch sg-freebsd-port.c for such an implementation.
@@ -1685,7 +1683,7 @@ int scsi_enumerate_drives(void)
 
 /** Tells wether libburn has the given drive in use or exclusively reserved.
     If it is "open" then libburn will eventually call sg_release() on it when
-    it is time to give up usage resp. reservation.
+    it is time to give up usage and reservation.
 */
 /** Published as burn_drive.drive_is_open() */
 int sg_drive_is_open(struct burn_drive * d)
@@ -2006,7 +2004,7 @@ static int evaluate_transport_success(struct burn_drive *d, struct command *c,
 		give_up_drive= 1;
 	break; case 0x80:
 		driver_sugg = "SG_ERR_SUGGEST_SENSE";
-	default:
+	break; default:
 		driver_sugg = "(unknown driver_status suggestion)";
 	}
 	if ((driver_status & 0xf7) != Libburn_sg_driver_oK) {
@@ -2130,6 +2128,26 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 		s.timeout = Libburn_scsi_default_timeouT;
 	if (c->page && !no_c_page) {
 		s.dxferp = c->page->data;
+
+/* # def ine Libburn_debug_dxferP 1 */
+#ifdef Libburn_debug_dxferP
+
+		{ char text[1024], *content; int i = c->page->bytes;
+			if (c->dir == FROM_DRIVE) {
+				for (i = 0; i < c->page->bytes && c->page->data[i] == 0; i++);
+				content = (i <  c->page->bytes) ?
+					  "  (some nonzero)" : "  (all zero)";
+			} else {
+				i = c->page->bytes;
+				content = "";
+			}
+			sprintf(text, "dxferp before = %lx%s",
+					(unsigned long) s.dxferp, content);
+			scsi_log_text(text, fp, 0);
+		}
+
+#endif
+
 		if (c->dir == FROM_DRIVE) {
 
 			/* ts A70519 : kernel 2.4 usb-storage seems to
@@ -2169,22 +2187,15 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 
 		c->end_time = burn_get_time(0);
 
-/*
- # de fine Libburn_ff_netbsd_mockuP
- */
-#ifdef Libburn_ff_netbsd_mockuP
-		if (c->opcode[0] == 0x5a) {
-			sprintf(msg, "Libburn_ff_netbsd_mockuP : Emulating zero reply from SCSI command 5A");
-			if (burn_sg_log_scsi & 3)
-				scsi_log_message(d, fp, msg, 0);
-			libdax_msgs_submit(libdax_messenger,
-				d->global_index, 0x00000002,
-				LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
-				msg, 0, 0);
-			memset(c->page->data, 0, c->page->bytes);
-			c->error = 1;
-			c->dxfer_len = 0;
+
+#ifdef Libburn_debug_dxferP
+		if (c->page && !no_c_page) {
+			char text[1024];
+			sprintf(text, "dxferp after  = %lx",
+					(unsigned long) s.dxferp);
+			scsi_log_text(text, fp, 0);
 		}
+
 #endif
 
 		/* ts A61010 */
@@ -2382,7 +2393,6 @@ int burn_os_stdio_capacity(char *path, off_t write_start, off_t *bytes)
 
 	BURN_ALLOC_MEM(testpath, char, 4096);
 	testpath[0] = 0;
-	blocks = *bytes / 512;
 	if (stat(path, &stbuf) == -1) {
 		strcpy(testpath, path);
 		cpt = strrchr(testpath, '/');
